A simple examples for testing resolution.

1. gen_toy.py

   generate toy data

2. gauss_sample.py / gauss_random.py

   using data to generate gauss point of data

3. ../../fit.py

   fit data

4. plot_resolution.py

   plot fit with resolution

Or use following command to run all scripts

```
./run_all.sh
```
